@@ -30,12 +30,12 @@
 #include "edid.h"
 #include "gnome-rr-private.h"
 
-G_DEFINE_TYPE (GnomeRROutputInfo, gnome_rr_output_info, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeRROutputInfo, gnome_rr_output_info, G_TYPE_OBJECT)
 
 static void
 gnome_rr_output_info_init (GnomeRROutputInfo *self)
 {
-    self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GNOME_TYPE_RR_OUTPUT_INFO, GnomeRROutputInfoPrivate);
+    self->priv = gnome_rr_output_info_get_instance_private (self);
 
     self->priv->name = NULL;
     self->priv->on = FALSE;
@@ -59,8 +59,6 @@ gnome_rr_output_info_class_init (GnomeRROutputInfoClass *klass)
 {
     GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-    g_type_class_add_private (klass, sizeof (GnomeRROutputInfoPrivate));
-
     gobject_class->finalize = gnome_rr_output_info_finalize;
 }
 
