@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  */
 
@@ -27,6 +27,8 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
+#include <pulse/pulseaudio.h>
+
 #include "gvc-channel-map.h"
 #include "gvc-channel-map-private.h"
 
@@ -225,6 +227,7 @@ gvc_channel_map_get_mapping (const GvcChannelMap  *map)
 
 /**
  * gvc_channel_map_has_position:
+ * @map:
  * @position: (type int)
  *
  * Returns:
